# Variables d'environnement
NO_DB_DUMP :  
if not already existing, preview will be mounted without dump from prod instance, but with demo datas  

MODULES_WITHOUT_DEMO :  
list of modules for --without-demo option (modules that will be loaded without demo data) 

# Dev interaction
### lancement en local pour tester le mode interactif : python -m pynestor preview --interactive --up
